==> visualvm_2.1.5.orig.tar.xz: visualvm-2.1.5/visualvm/appui/src/org/graalvm/visualvm/modules/appui/keystore/CacertsKeyStoreProvider.java <==
/*
 * Copyright (c) 2020, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

package org.graalvm.visualvm.modules.appui.keystore;

import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.security.KeyStore;
import java.util.logging.Level;
import java.util.logging.Logger;
import org.netbeans.spi.autoupdate.KeyStoreProvider;

/**
 * The cacerts keystore with the configured CA certificates.
 *
 * @author Tomas Hurka
 */
public class CacertsKeyStoreProvider implements KeyStoreProvider {

    private static String getCacerts() {
        String fs = File.separator;
        // ${java_home}/lib/security/cacerts
        return System.getProperty("java.home") + fs
              + "lib" + fs + "security" + fs + "cacerts";
    }

    /**
     * Returns the cacerts keystore with the configured CA certificates.
     */
    @Override
    public KeyStore getKeyStore() {
        KeyStore keyStore = null;
        FileInputStream is = null;

        try {
            File file = new File(getCacerts());
            if (!file.exists()) {
                return null;
            }

            keyStore = KeyStore.getInstance(KeyStore.getDefaultType());
            is = new FileInputStream(file);
            keyStore.load(is, null);
        } catch (Exception ex) {
            Logger.getLogger("global").log(Level.INFO, ex.getMessage(), ex);
        } finally {
            try {
                if (is != null) is.close();
            } catch (IOException ex) {
                assert false : ex;
            }
        }
        return keyStore;
    }

    @Override
    public TrustLevel getTrustLevel() {
        return TrustLevel.VALIDATE_CA;
    }
}

==> visualvm_2.1.8.orig.tar.xz: visualvm-2.1.8/visualvm/appui/src/org/graalvm/visualvm/modules/appui/keystore/CacertsKeyStoreProvider.java <==
/*
 * Copyright (c) 2020, 2022, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

package org.graalvm.visualvm.modules.appui.keystore;

import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.security.KeyStore;
import java.util.logging.Level;
import java.util.logging.Logger;
import org.netbeans.spi.autoupdate.KeyStoreProvider;
import org.openide.util.lookup.ServiceProvider;

/**
 * The cacerts keystore with the configured CA certificates.
 *
 * @author Tomas Hurka
 */
@ServiceProvider(service=KeyStoreProvider.class)
public class CacertsKeyStoreProvider implements KeyStoreProvider {

    private static String getCacerts() {
        String fs = File.separator;
        // ${java_home}/lib/security/cacerts
        return System.getProperty("java.home") + fs
              + "lib" + fs + "security" + fs + "cacerts";
    }

    /**
     * Returns the cacerts keystore with the configured CA certificates.
     */
    @Override
    public KeyStore getKeyStore() {
        KeyStore keyStore = null;
        FileInputStream is = null;

        try {
            File file = new File(getCacerts());
            if (!file.exists()) {
                return null;
            }

            keyStore = KeyStore.getInstance(KeyStore.getDefaultType());
            is = new FileInputStream(file);
            keyStore.load(is, null);
        } catch (Exception ex) {
            Logger.getLogger("global").log(Level.INFO, ex.getMessage(), ex);
        } finally {
            try {
                if (is != null) is.close();
            } catch (IOException ex) {
                assert false : ex;
            }
        }
        return keyStore;
    }

    @Override
    public TrustLevel getTrustLevel() {
        return TrustLevel.TRUST;
    }
}
